Changelog
---------

v1.8.0 (2020-04-15)
~~~~~~~~~~~~~~~~~~~

* merged template changes from Django 1.8
* testing project updated for Django 1.8


v1.7.4 (2015-05-08)
~~~~~~~~~~~~~~~~~~~

* small updates in styles
* typo fixed in one translation
* requirements in test project updated


v1.7.3 (2015-04-20)
~~~~~~~~~~~~~~~~~~~

* another fix for small visual regression


v1.7.2 (2015-03-24)
~~~~~~~~~~~~~~~~~~~

* fixed small visual regression
* added Dutch translation (thanks to Rico Moorman)


v1.7.1 (2015-03-23)
~~~~~~~~~~~~~~~~~~~

* change list page template modified to include object-tools and object-tools-items blocks
* styles modified to style added blocks
* small cleanup in some templates
* added new translations: Bulgarian (thanks to Metodi Dejanov), French (thanks to qmarlats), Portuguese (Brazil) (thanks to Kaio Henrique).
* updated docs about translations
* Font Awesome updated to version 4.3.0
* Less updated to version 2.4.0


v1.7.0 (2014-11-24)
~~~~~~~~~~~~~~~~~~~

* merged template changes from Django 1.7
* using new features (site_header and site_title) of AdminSite from Django 1.7
* testing project updated for Django 1.7
* small updates in styles


v1.6.3 (2014-11-20)
~~~~~~~~~~~~~~~~~~~

* fix for tabular inlines
* added sample tabular and stacked inlines in test project
* added new translations: German (thanks to Silasoa), Indonesian (thanks to Al Firdaus), Italian (thanks to Giuseppe Pignataro), Russian (thanks to Eugene MechanisM).
* updated docs about translations
* Font Awesome updated to version 4.2.0
* Less updated to version 2.0.0
* jQuery Cookie plugin updated to version 1.4.1
* added 2 new color themes: milo and milo-light


v1.6.2 (2014-03-21)
~~~~~~~~~~~~~~~~~~~

* fix for top menu hover colors in themes
* added color theme chooser on user panel in test project


v1.6.1 (2014-03-13)
~~~~~~~~~~~~~~~~~~~

* Python3 compatibility
* updated templates for password reset and change (from /registration template path)
* updated template for login page to make it more consistent with rest of the pages
* fixed bug with submenu when left menu is folded
* more fixes for small resolutions screens
* proper login forms in test project used


v1.6.0 (2014-03-11)
~~~~~~~~~~~~~~~~~~~

* **backward compatibility breaking release!**
* most of things was rewritten
* from now on there will be separate branch for each major Django version and Django WP Admin will be versioned according to Django version it supports...
* ...so this version is compatible only with Django 1.6.x
* all JavaScript libraries updated
* FontAwesome updated to version 4.0.3
* new WordPress admin look
* styles for selector widget
* styles for calendar widget
* styles for timepicker widget
* styles for delete confirmation page
* styles for history page
* collapsible fieldsets can be opened by default
* support for nested submenus
* 7 additional color themes added
* added licenses for all included external files (fonts and JS)


v0.2.0 (2013-04-02)
~~~~~~~~~~~~~~~~~~~

* styled object's editing pages


v0.1.2 (2013-03-23)
~~~~~~~~~~~~~~~~~~~

* **Django 1.3 support dropped!** (there's too much differences between Django 1.3 and 1.4)
* installation process slightly changed (there's no need to copy or symlink base.html file for specific Django version)
* added WordPress look and feel for objects lists (change_list.html)
* CHANGELOG added


v0.1.1 (2013-03-19)
~~~~~~~~~~~~~~~~~~~

* installation scripts
* README and LICENSE files added


v0.1.0 (2013-03-19)
~~~~~~~~~~~~~~~~~~~

* top and left menu
